@@ -346,11 +346,11 @@ class text:
                 for j in range(2):
                     for k in range(2):
                          # print org + i*ab[1] + j*ab[2] + k*vector(0.,0.,xsize*thickness)).__class__
-                         b.append(pos=tuple(org + i*ab[1] + j*ab[2] + k*vector(0.,0.,xsize*thickness)))
+                         b.append(pos=(org + i*ab[1] + j*ab[2] + k*vector(0.,0.,xsize*thickness)))
         else:
             for i in range(2):
                 for j in range(2):
-                         b.append(pos=tuple(org + i*ab[1] + j*ab[2]))
+                         b.append(pos=(org + i*ab[1] + j*ab[2]))
 
     def showletter(self, origin, char, xsize, ysize,
                    thickness, color, container, visible):
