@@ -11,6 +11,10 @@
 /***************** GLDevice *******************/
 
 namespace visual {
+
+glFont::~glFont()
+{
+}
 	
 GLDevice::GLDevice()
 	: mode(HIDE),
@@ -255,7 +259,7 @@ GLDevice::getProjection( tmatrix& wct, vector& cam, int eyesign)
 	int width = cx.width();
 	//JMZ passive stereo each view is 1/2 width of window
 	//  now use width throughout rather than cx.width()
-	if (initstereo == PASSIVE) {
+	if (initstereo == PASSIVE || initstereo == CROSSEYED) {
 		width /= 2;
 	}
 
@@ -672,7 +676,7 @@ GLDevice::render_control()
 		int flags = glContext::DEFAULT;
 		if (initfull)
 			flags |= glContext::FULLSCREEN;
-		if (initstereo == PASSIVE){
+		if (initstereo == PASSIVE || initstereo == CROSSEYED){
 			initw *= 2;  // double window width for two views
 		}
 		else if (initstereo == ACTIVE){
@@ -739,6 +743,14 @@ GLDevice::render_control()
 			glViewport( cx.width()/2+1, 0, cx.width()/2, cx.height());
 			draw( 1, true, false, false);
 			break;
+		case CROSSEYED: // side-by-side passive stereo
+			// This mode is the same as PASSIVE, but the left pane holds the
+			// view for the right eye
+			glViewport( 0, 0, cx.width()/2, cx.height());
+			draw( 1, false, false, false);
+			glViewport( cx.width()/2+1, 0, cx.width()/2, cx.height());
+			draw( -1, true, false, false);
+			break;
 		case RED_BLUE: // Color separation
 			// Red channel
 			glClear( GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT );
